@@ -6,9 +6,9 @@
 #endif
 
 #ifndef EIGHTBIT_SUBIDS
-typedef uint32_t oid;
+typedef u_long oid;
 #define MAX_SUBID   0xFFFFFFFF
-#define NETSNMP_PRIo NETSNMP_PRI32
+#define NETSNMP_PRIo "l"
 #else
 typedef uint8_t oid;
 #define MAX_SUBID   0xFF
