@@ -4,6 +4,8 @@
 #define openbsd openbsd
 #define UVM
 
+#undef MBPOOL_SYMBOL
+#undef MCLPOOL_SYMBOL
 #undef TOTAL_MEMORY_SYMBOL
 
 /* at least OpenBSD/SPARC 3.7 doesn't define this */
